# Generated by Django 5.2.6 on 2025-10-01 19:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('dcim', '0215_rackreservation_status'),
        ('ipam', '0082_add_prefix_network_containment_indexes'),
        ('netbox_services', '0002_alter_service_asns_alter_service_cables_and_more'),
        ('virtualization', '0048_populate_mac_addresses'),
        ('vpn', '0009_remove_redundant_indexes'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='service',
            options={'ordering': ['service_id']},
        ),
        migrations.AlterField(
            model_name='service',
            name='asns',
            field=models.ManyToManyField(to='ipam.asn'),
        ),
        migrations.AlterField(
            model_name='service',
            name='cables',
            field=models.ManyToManyField(to='dcim.cable'),
        ),
        migrations.AlterField(
            model_name='service',
            name='devices',
            field=models.ManyToManyField(to='dcim.device'),
        ),
        migrations.AlterField(
            model_name='service',
            name='interfaces',
            field=models.ManyToManyField(to='dcim.interface'),
        ),
        migrations.AlterField(
            model_name='service',
            name='l2vpns',
            field=models.ManyToManyField(to='vpn.l2vpn'),
        ),
        migrations.AlterField(
            model_name='service',
            name='prefixes',
            field=models.ManyToManyField(to='ipam.prefix'),
        ),
        migrations.AlterField(
            model_name='service',
            name='route_targets',
            field=models.ManyToManyField(to='ipam.routetarget'),
        ),
        migrations.AlterField(
            model_name='service',
            name='tunnels',
            field=models.ManyToManyField(to='vpn.tunnel'),
        ),
        migrations.AlterField(
            model_name='service',
            name='virtual_machines',
            field=models.ManyToManyField(to='virtualization.virtualmachine'),
        ),
        migrations.AlterField(
            model_name='service',
            name='vlans',
            field=models.ManyToManyField(to='ipam.vlan'),
        ),
    ]
