# Generated by Django 5.2.6 on 2025-10-02 19:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_services', '0003_alter_service_options_alter_service_asns_and_more'),
    ]

    operations = [
        migrations.RenameField(
            model_name='service',
            old_name='vrf',
            new_name='vrfs',
        ),
        migrations.AlterField(
            model_name='service',
            name='service_id',
            field=models.CharField(unique=True),
        ),
    ]
